@@ -3,13 +3,15 @@ use warnings;
 
 package WebService::Shippo;
 # ABSTRACT: A Shippo Perl API wrapper
-our $VERSION = '0.0.6';
+our $VERSION = '0.0.7';
 require WebService::Shippo::Entities;
 require WebService::Shippo::Request;
 require WebService::Shippo::Config;
+use Params::Callbacks ( 'callbacks', 'callback' );
 use base ( 'Exporter' );
 
 our @EXPORT_OK = qw(
+    callback
     shippo_address
     shippo_address_list
     shippo_address_validate
@@ -44,69 +46,69 @@ our @EXPORT_OK = qw(
     shippo_transaction_list
     shippo_transaction_create
 );
-our %EXPORT_TAGS = ( all => \@EXPORT_OK );
+our %EXPORT_TAGS = ( all => \@EXPORT_OK, ALL => \@EXPORT_OK );
 
 #<<< Don't Perl Tidy this
-sub shippo_address                    { Shippo::Address->get( @_ ) }
-sub shippo_address_list               { Shippo::Address->all( @_ ) }
-sub shippo_address_validate           { Shippo::Address->validate( @_ ) }
-sub shippo_address_create             { Shippo::Address->create( @_ ) }
-sub shippo_carrier_account            { Shippo::CarrierAccount->get( @_ ) }
-sub shippo_carrier_account_list       { Shippo::CarrierAccount->all( @_ ) }
-sub shippo_carrier_account_create     { Shippo::CarrierAccount->create( @_ ) }
-sub shippo_carrier_account_update     { Shippo::CarrierAccount->update( @_ ) }
-sub shippo_customs_declaration        { Shippo::CustomsDeclaration->get( @_ ) }
-sub shippo_customs_declaration_list   { Shippo::CustomsDeclaration->all( @_ ) }
-sub shippo_customs_declaration_create { Shippo::CustomsDeclaration->create( @_ ) }
-sub shippo_customs_item               { Shippo::CustomsItem->get( @_ ) }
-sub shippo_customs_item_list          { Shippo::CustomsItem->all( @_ ) }
-sub shippo_customs_item_create        { Shippo::CustomsItem->create( @_ ) }
-sub shippo_manifest                   { Shippo::Manifest->get( @_ ) }
-sub shippo_manifest_list              { Shippo::Manifest->all( @_ ) }
-sub shippo_manifest_create            { Shippo::Manifest->create( @_ ) }
-sub shippo_parcel                     { Shippo::Parcel->get( @_ ) }
-sub shippo_parcel_list                { Shippo::Parcel->all( @_ ) }
-sub shippo_parcel_create              { Shippo::Parcel->create( @_ ) }
-sub shippo_rate                       { Shippo::Rate->get( @_ ) }
-sub shippo_rate_list                  { Shippo::Rate->all( @_ ) }
-sub shippo_refund                     { Shippo::Refund->get( @_ ) }
-sub shippo_refund_list                { Shippo::Refund->all( @_ ) }
-sub shippo_refund_create              { Shippo::Refund->create( @_ ) }
-sub shippo_shipment                   { Shippo::Shipment->get( @_ ) }
-sub shippo_shipment_list              { Shippo::Shipment->all( @_ ) }
-sub shippo_shipment_create            { Shippo::Shipment->create( @_ ) }
-sub shippo_shipment_rates             { Shippo::Shipment->rates( @_ ) }
-sub shippo_return_shipment_create     { Shippo::ReturnShipment->create( @_ ) }
-sub shippo_transaction                { Shippo::Transaction->get( @_ ) }
-sub shippo_transaction_list           { Shippo::Transaction->all( @_ ) }
-sub shippo_transaction_create         { Shippo::Transaction->create( @_ ) }
+sub shippo_address                    { WebService::Shippo::Address->get( @_ ) }
+sub shippo_address_list               { WebService::Shippo::Address->all( @_ ) }
+sub shippo_address_validate           { WebService::Shippo::Address->validate( @_ ) }
+sub shippo_address_create             { WebService::Shippo::Address->create( @_ ) }
+sub shippo_carrier_account            { WebService::Shippo::CarrierAccount->get( @_ ) }
+sub shippo_carrier_account_list       { WebService::Shippo::CarrierAccount->all( @_ ) }
+sub shippo_carrier_account_create     { WebService::Shippo::CarrierAccount->create( @_ ) }
+sub shippo_carrier_account_update     { WebService::Shippo::CarrierAccount->update( @_ ) }
+sub shippo_customs_declaration        { WebService::Shippo::CustomsDeclaration->get( @_ ) }
+sub shippo_customs_declaration_list   { WebService::Shippo::CustomsDeclaration->all( @_ ) }
+sub shippo_customs_declaration_create { WebService::Shippo::CustomsDeclaration->create( @_ ) }
+sub shippo_customs_item               { WebService::Shippo::CustomsItem->get( @_ ) }
+sub shippo_customs_item_list          { WebService::Shippo::CustomsItem->all( @_ ) }
+sub shippo_customs_item_create        { WebService::Shippo::CustomsItem->create( @_ ) }
+sub shippo_manifest                   { WebService::Shippo::Manifest->get( @_ ) }
+sub shippo_manifest_list              { WebService::Shippo::Manifest->all( @_ ) }
+sub shippo_manifest_create            { WebService::Shippo::Manifest->create( @_ ) }
+sub shippo_parcel                     { WebService::Shippo::Parcel->get( @_ ) }
+sub shippo_parcel_list                { WebService::Shippo::Parcel->all( @_ ) }
+sub shippo_parcel_create              { WebService::Shippo::Parcel->create( @_ ) }
+sub shippo_rate                       { WebService::Shippo::Rate->get( @_ ) }
+sub shippo_rate_list                  { WebService::Shippo::Rate->all( @_ ) }
+sub shippo_refund                     { WebService::Shippo::Refund->get( @_ ) }
+sub shippo_refund_list                { WebService::Shippo::Refund->all( @_ ) }
+sub shippo_refund_create              { WebService::Shippo::Refund->create( @_ ) }
+sub shippo_shipment                   { WebService::Shippo::Shipment->get( @_ ) }
+sub shippo_shipment_list              { WebService::Shippo::Shipment->all( @_ ) }
+sub shippo_shipment_create            { WebService::Shippo::Shipment->create( @_ ) }
+sub shippo_shipment_rates             { WebService::Shippo::Shipment->rates( @_ ) }
+sub shippo_return_shipment_create     { WebService::Shippo::ReturnShipment->create( @_ ) }
+sub shippo_transaction                { WebService::Shippo::Transaction->get( @_ ) }
+sub shippo_transaction_list           { WebService::Shippo::Transaction->all( @_ ) }
+sub shippo_transaction_create         { WebService::Shippo::Transaction->create( @_ ) }
 #>>>
 
-BEGIN {
-    no warnings 'once';
-    # There are some useful mutators defined elsewhere that I'd like to
-    # make available (alias) via the root namespace.
-    *api_key  = *WebService::Shippo::Resource::api_key;
-    *PRETTY   = *WebService::Shippo::Object::PRETTY;
-    *response = *WebService::Shippo::Request::response;
-    *Response = *WebService::Shippo::Request::response;
-         # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
-         # namespace is just cruel; allow the use of "Shippo", too.
-    *Shippo:: = *WebService::Shippo::;
-}
-
 sub import
 {
     my ( $class ) = @_;
     # Configure Shippo client on import
-    Shippo::Config->config;
+    WebService::Shippo::Config->config;
     # The API key is overridden with the envornment's value if defined.
-    Shippo::Resource->api_key( $ENV{SHIPPO_TOKEN} )
+    WebService::Shippo::Resource->api_key( $ENV{SHIPPO_TOKEN} )
         if $ENV{SHIPPO_TOKEN};
-    # Pass call frame to Exporter's import for it's processing
+    # Pass call frame to Exporter's import for further processing
     goto &Exporter::import;
 }
 
+BEGIN {
+    no warnings 'once';
+    # There are some useful symbols defined elsewhere that I'd like to
+    # make available (alias) via the root namespace.
+    *api_key  = *WebService::Shippo::Resource::api_key;
+    *PRETTY   = *WebService::Shippo::Object::PRETTY;
+    *response = *WebService::Shippo::Request::response;
+    *Response = *WebService::Shippo::Request::response;
+    # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
+    # namespace is just cruel; allow the use of "Shippo", too.
+    *Shippo:: = *WebService::Shippo::;
+}
+
 1;
 
 =pod
@@ -119,7 +121,9 @@ WebService::Shippo - A Shippo API Perl Wrapper (coming soon)
 
 =head1 VERSION
 
-version 0.0.6
+0.0.7 
+
+Built 2015-10-20 (no more changes until 2015-10-23 - I'm out of town).
 
 =head1 UNDER CONSTRUCTION
 
