@@ -11,11 +11,17 @@ use base ( 'WebService::Shippo::Creator',
 
 sub api_resource {'customs/declarations'}
 
+package    # Hide from PAUSE
+    WebService::Shippo::CustomsDeclarationList;
+use base ( 'WebService::Shippo::ObjectList' );
+
 BEGIN {
     no warnings 'once';
     # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
     # namespace is just cruel; allow the use of "Shippo", too.
     *Shippo::CustomsDeclaration:: = *WebService::Shippo::CustomsDeclaration::;
+    *Shippo::CustomsDeclarationList::
+        = *WebService::Shippo::CustomsDeclarationList::;
 }
 
 1;
