@@ -11,11 +11,16 @@ use base ( 'WebService::Shippo::Creator',
 
 sub api_resource {'customs/items'}
 
+package    # Hide from PAUSE
+    WebService::Shippo::CustomsItemList;
+use base ( 'WebService::Shippo::ObjectList' );
+
 BEGIN {
     no warnings 'once';
     # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
     # namespace is just cruel; allow the use of "Shippo", too.
-    *Shippo::CustomsItem:: = *WebService::Shippo::CustomsItem::;
+    *Shippo::CustomsItem::     = *WebService::Shippo::CustomsItem::;
+    *Shippo::CustomsItemList:: = *WebService::Shippo::CustomsItemList::;
 }
 
 1;
