@@ -11,11 +11,16 @@ use base ( 'WebService::Shippo::Creator',
 
 sub api_resource {'manifests'}
 
+package    # Hide from PAUSE
+    WebService::Shippo::ManifestList;
+use base ( 'WebService::Shippo::ObjectList' );
+
 BEGIN {
     no warnings 'once';
     # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
     # namespace is just cruel; allow the use of "Shippo", too.
-    *Shippo::Manifest:: = *WebService::Shippo::Manifest::;
+    *Shippo::Manifest::     = *WebService::Shippo::Manifest::;
+    *Shippo::ManifestList:: = *WebService::Shippo::ManifestList::;
 }
 
 1;
