@@ -2,8 +2,10 @@ use strict;
 use warnings;
 
 package WebService::Shippo::Request;
+use Carp        ( 'confess' );
 use JSON::XS    ();
 use LWP         ();
+use Clone       ( 'clone' );
 use URI::Encode ( 'uri_encode' );
 
 {
@@ -23,7 +25,8 @@ use URI::Encode ( 'uri_encode' );
         return $value unless @_ > 1;
         $value = $new_value;
         if ( $value->can( 'agent' ) ) {
-            my $prod = 'Shippo/' . WebService::Shippo::Resource->DEFAULT_API_BASE_PATH;
+            my $prod = 'Shippo/';
+            $prod .= WebService::Shippo::Resource->DEFAULT_API_VERSION;
             $prod .= " WebService\::Shippo/$WebService::Shippo::VERSION";
             $prod .= ' ' . $value->_agent
                 if $value->can( '_agent' );
@@ -32,8 +35,6 @@ use URI::Encode ( 'uri_encode' );
         }
         return $class;
     }
-
-    __PACKAGE__->user_agent( LWP::UserAgent->new );
 }
 
 sub query_string
@@ -52,36 +53,66 @@ sub query_string
     return '?' . join( ';', @pairs );
 }
 
-sub get
 {
-    my ( $invocant, $url, $params ) = @_;
-    $url .= $invocant->query_string( $params );
-    my $response = user_agent->get( $url, headers );
-    return $response;
-}
+    my $json          = JSON::XS->new->utf8->convert_blessed->allow_blessed;
+    my $last_response = undef;
 
-{
-    my $json = JSON::XS->new->utf8;
+    sub handle_failed_request
+    {
+        my ( $invocant ) = @_;
+        confess $last_response->status_line . "\n" . $last_response->content
+            . "\n\tFailed request";
+    }
+
+    sub get
+    {
+        my ( $invocant, $url, @params ) = @_;
+        @params = ({})
+            unless @params;
+        my $params = ref( $params[0] ) ? $params[0] : {@params};
+        $url .= $invocant->query_string( $params );
+        my $response = user_agent->get( $url, headers );
+        $last_response = clone( $response );
+        unless ( $response->is_success ) {
+
+        }
+        $invocant->handle_failed_request
+            unless $response->is_success;
+        return $response;
+    }
 
     sub put
     {
-        my ( $invocant, $url, $params ) = @_;
-        my $payload = $json->encode( {%$params} );
+        my ( $invocant, $url, @params ) = @_;
+        @params = ({})
+            unless @params;
+        my $params = ref( $params[0] ) ? $params[0] : {@params};
+        my $payload = $json->encode( $params );
         my $response = user_agent->put( $url, headers, Content => $payload );
+        $last_response = clone( $response );
+        $invocant->handle_failed_request
+            unless $response->is_success;
         return $response;
     }
-}
-
-{
-    my $json = JSON::XS->new->utf8;
 
     sub post
     {
-        my ( $invocant, $url, $params ) = @_;
-        my $payload = $json->encode( {%$params} );
+        my ( $invocant, $url, @params ) = @_;
+        @params = ({})
+            unless @params;
+        my $params = ref( $params[0] ) ? $params[0] : {@params};
+        my $payload = $json->encode( $params );
         my $response = user_agent->post( $url, headers, Content => $payload );
+        $last_response = clone( $response );
+        $invocant->handle_failed_request
+            unless $response->is_success;
         return $response;
     }
+
+    sub response
+    {
+        return $last_response;
+    }
 }
 
 BEGIN {
@@ -91,4 +122,7 @@ BEGIN {
     *Shippo::Request:: = *WebService::Shippo::Request::;
 }
 
+# Init the user_agent attribute, and all that entails...
+__PACKAGE__->user_agent( LWP::UserAgent->new );
+
 1;
